@@ -1,15 +1,15 @@
+"""Design interface using Zur algorithm and Anderson rule."""
+
 from itertools import product
 import numpy as np
 from jarvis.core.atoms import Atoms
-from jarvis.io.vasp.inputs import Poscar
 from jarvis.core.lattice import Lattice
-import json
-import joblib, pickle
 
 
 class ZSLGenerator(object):
     """
-    Uses Zur algorithm to find best matched interfaces
+    Uses Zur algorithm to find best matched interfaces.
+
     This class is modified from pymatgen.
     """
 
@@ -21,18 +21,18 @@ class ZSLGenerator(object):
         max_angle_tol=0.01,
     ):
         """
-        Intialize a Zur Super Lattice Generator for a specific film and
-            substrate
-            
+        Intialize for a specific film and substrate.
+
+        Parameters for the class.
         Args:
             max_area_ratio_tol(float): Max tolerance on ratio of
                 super-lattices to consider equal
-                
+
             max_area(float): max super lattice area to generate in search
-            
+
             max_length_tol: maximum length tolerance in checking if two
                 vectors are of nearly the same length
-                
+
             max_angle_tol: maximum angle tolerance in checking of two sets
                 of vectors have nearly the same angle between them
         """
@@ -43,18 +43,18 @@ class ZSLGenerator(object):
 
     def is_same_vectors(self, vec_set1, vec_set2):
         """
-        Determine if two sets of vectors are the same within length and angle
-        tolerances
-        
+        Check two sets of vectors are the same.
+
         Args:
             vec_set1(array[array]): an array of two vectors
-            
+
             vec_set2(array[array]): second array of two vectors
-            
         """
-        if np.absolute(rel_strain(vec_set1[0], vec_set2[0])) > self.max_length_tol:
+        if np.absolute(rel_strain(vec_set1[0],
+                       vec_set2[0])) > self.max_length_tol:
             return False
-        elif np.absolute(rel_strain(vec_set1[1], vec_set2[1])) > self.max_length_tol:
+        elif np.absolute(rel_strain(vec_set1[1],
+                         vec_set2[1])) > self.max_length_tol:
             return False
         elif np.absolute(rel_angle(vec_set1, vec_set2)) > self.max_angle_tol:
             return False
@@ -62,20 +62,18 @@ class ZSLGenerator(object):
             return True
 
     def generate_sl_transformation_sets(self, film_area, substrate_area):
-        """
-        Generates transformation sets for film/substrate pair given the
-        area of the unit cell area for the film and substrate. The
-        transformation sets map the film and substrate unit cells to super
-        lattices with a maximum area
-        
+        """Generate transformation sets for film/substrate.
+
+        The transformation sets map the film and substrate unit cells to super
+        lattices with a maximum area.
+
         Args:
-        
-            film_area(int): the unit cell area for the film
-            
-            substrate_area(int): the unit cell area for the substrate
-            
+
+            film_area(int): the unit cell area for the film.
+
+            substrate_area(int): the unit cell area for the substrate.
+
         Returns:
-        
             transformation_sets: a set of transformation_sets defined as:
                 1.) the transformation matricies for the film to create a
                 super lattice of area i*film area
@@ -93,35 +91,37 @@ class ZSLGenerator(object):
         # Sort sets by the square of the matching area and yield in order
         # from smallest to largest
         for x in sorted(transformation_indicies, key=lambda x: x[0] * x[1]):
-            yield (gen_sl_transform_matricies(x[0]), gen_sl_transform_matricies(x[1]))
+            yield (gen_sl_transform_matricies(x[0]),
+                   gen_sl_transform_matricies(x[1]))
 
     def get_equiv_transformations(
         self, transformation_sets, film_vectors, substrate_vectors
     ):
         """
-        Applies the transformation_sets to the film and substrate vectors
-        to generate super-lattices and checks if they matches.
+        Apply the transformation_sets to the film and substrate vectors.
+
+        Generate super-lattices and checks if they matches.
         Returns all matching vectors sets.
-        
+
         Args:
-        
             transformation_sets(array): an array of transformation sets:
                 each transformation set is an array with the (i,j)
                 indicating the area multipes of the film and subtrate it
                 corresponds to, an array with all possible transformations
                 for the film area multiple i and another array for the
                 substrate area multiple j.
-                
-            film_vectors(array): film vectors to generate super lattices
-            
+
+            film_vectors(array): film vectors to generate super lattices.
+
             substrate_vectors(array): substrate vectors to generate super
                 lattices
         """
-
-        for (film_transformations, substrate_transformations) in transformation_sets:
+        for (film_transformations,
+             substrate_transformations) in transformation_sets:
             # Apply transformations and reduce using Zur reduce methodology
             films = [
-                reduce_vectors(*np.dot(f, film_vectors)) for f in film_transformations
+                reduce_vectors(*np.dot(f, film_vectors)
+                               ) for f in film_transformations
             ]
 
             substrates = [
@@ -138,11 +138,7 @@ class ZSLGenerator(object):
                     yield [f, s, f_trans, s_trans]
 
     def __call__(self, film_vectors, substrate_vectors, lowest=False):
-        """
-        Runs the ZSL algorithm to generate all possible matching
-        :return:
-        """
-
+        """Run the ZSL algorithm to generate all possible matching."""
         film_area = vec_area(*film_vectors)
         substrate_area = vec_area(*substrate_vectors)
 
@@ -167,7 +163,6 @@ class ZSLGenerator(object):
                 match[3],
             )
 
-            # Just want lowest match per direction
             if lowest:
                 break
 
@@ -182,12 +177,11 @@ class ZSLGenerator(object):
         substrate_transformation,
     ):
         """
-        Returns dict which contains ZSL match
-        
+        Return dict which contains ZSL match.
+
         Args:
-        
             film_miller(array)
-            
+
             substrate_miller(array)
         """
         d = {}
@@ -204,21 +198,21 @@ class ZSLGenerator(object):
 
 def gen_sl_transform_matricies(area_multiple):
     """
-    Generates the transformation matricies that convert a set of 2D
-    vectors into a super lattice of integer area multiple as proven
+    Generate the transformation matricies.
+
+    Convert a set of 2D vectors into a super
+    lattice of integer area multiple as proven
     in Cassels:
     Cassels, John William Scott. An introduction to the geometry of
     numbers. Springer Science & Business Media, 2012.
-    
+
     Args:
-    
         area_multiple(int): integer multiple of unit cell area for super
-        lattice area
-        
+        lattice area.
+
     Returns:
         matrix_list: transformation matricies to covert unit vectors to
-        super lattice vectors
-        
+        super lattice vectors.
     """
     return [
         np.array(((i, j), (0, area_multiple / i)))
@@ -228,100 +222,75 @@ def gen_sl_transform_matricies(area_multiple):
 
 
 def rel_strain(vec1, vec2):
-    """
-    Calculate relative strain between two vectors
-    """
+    """Calculate relative strain between two vectors."""
     return fast_norm(vec2) / fast_norm(vec1) - 1
 
 
 def rel_angle(vec_set1, vec_set2):
     """
-    Calculate the relative angle between two vector sets
-    
+    Calculate the relative angle between two vector sets.
+
     Args:
-        vec_set1(array[array]): an array of two vectors
-        
-        vec_set2(array[array]): second array of two vectors
+        vec_set1(array[array]): an array of two vectors.
+
+        vec_set2(array[array]): second array of two vectors.
     """
-    return vec_angle(vec_set2[0], vec_set2[1]) / vec_angle(vec_set1[0], vec_set1[1]) - 1
+    return vec_angle(vec_set2[0], vec_set2[1]
+                     ) / vec_angle(vec_set1[0], vec_set1[1]) - 1
 
 
 def fast_norm(a):
-    """
-    Much faster variant of numpy linalg norm
-    """
+    """Much faster variant of numpy linalg norm."""
     return np.sqrt(np.dot(a, a))
 
 
 def vec_angle(a, b):
-    """
-    Calculate angle between two vectors
-    """
+    """Calculate angle between two vectors."""
     cosang = np.dot(a, b)
     sinang = fast_norm(np.cross(a, b))
     return np.arctan2(sinang, cosang)
 
 
 def vec_area(a, b):
-    """
-    Area of lattice plane defined by two vectors
-    """
+    """Area of lattice plane defined by two vectors."""
     return fast_norm(np.cross(a, b))
 
 
 def reduce_vectors(a, b):
-    """
-    Generate independent and unique basis vectors based on the
-    methodology of Zur and McGill
-    """
+    """Generate independent and unique basis vectors based on Zur et al."""
     if np.dot(a, b) < 0:
         return reduce_vectors(a, -b)
-
     if fast_norm(a) > fast_norm(b):
         return reduce_vectors(b, a)
-
     if fast_norm(b) > fast_norm(np.add(b, a)):
         return reduce_vectors(a, np.add(b, a))
-
     if fast_norm(b) > fast_norm(np.subtract(b, a)):
         return reduce_vectors(a, np.subtract(b, a))
-
     return [a, b]
 
 
 def get_factors(n):
-    """
-    Generate all factors of n
-    """
+    """Generate all factors of n."""
     for x in range(1, n + 1):
         if n % x == 0:
             yield x
 
-  
-def make_interface(film='',subs='',atol=1,ltol=0.05):
-    """
-    Returns mismatch and other information as info dict
-    """
-
 
+def make_interface(film='', subs='', atol=1, ltol=0.05):
+    """Return mismatch and other information as info dict."""
     z = ZSLGenerator()
-
     matches = list(z(film.lattice_mat[:2], subs.lattice_mat[:2], lowest=True))
-
     info = {}
     info["mismatch_u"] = "na"
     info["mismatch_v"] = "na"
     info["mismatch_angle"] = "na"
     info["area1"] = "na"
     info["area2"] = "na"
-    info["film_sl"] = "na"#film
-    info['matches']= matches
-    info["subs_sl"] = "na"#subs
-
+    info["film_sl"] = "na"
+    info['matches'] = matches
+    info["subs_sl"] = "na"
     uv1 = matches[0]["sub_sl_vecs"]
     uv2 = matches[0]["film_sl_vecs"]
-    # uv1=[[-8.52917200e+00,  9.12745800e+00,  3.66344517e-17],[1.27937580e+01, 9.12745800e+00, 1.34228735e-15]]
-    # uv2=[[7.02403800e+00, 1.05360570e+01, 1.07524571e-15],[-1.40480760e+01,  7.02403800e+00, -4.30098283e-16]]
     u = np.array(uv1)
     v = np.array(uv2)
     a1 = u[0]
@@ -346,34 +315,21 @@ def make_interface(film='',subs='',atol=1,ltol=0.05):
     uv_substrate = uv1
     uv_film = uv2
     substrate_latt = Lattice(
-        np.array([uv_substrate[0][:], uv_substrate[1][:], subs.lattice_mat[2, :]])
+        np.array([uv_substrate[0][:],
+                 uv_substrate[1][:], subs.lattice_mat[2, :]])
     )
-
-    _, __, scell = subs.lattice.find_matches(substrate_latt, ltol=ltol, atol=atol)
-
-
+    _, __, scell = subs.lattice.find_matches(substrate_latt,
+                                             ltol=ltol, atol=atol)
     film_latt = Lattice(
         np.array([uv_film[0][:], uv_film[1][:], film.lattice_mat[2, :]])
     )
-
-
     scell[2] = np.array([0, 0, 1])
     scell_subs = scell
-
     _, __, scell = film.lattice.find_matches(film_latt, ltol=ltol, atol=atol)
     scell[2] = np.array([0, 0, 1])
     scell_film = scell
-
-
     film = film.make_supercell(scell_film)
     subs = subs.make_supercell(scell_subs)
-
-    lmap = Lattice(
-        np.array(
-            [subs.lattice_mat[0, :], subs.lattice_mat[1, :], film.lattice_mat[2, :]]
-        )
-    )
-
     film = film.center_around_origin()
     subs = subs.center_around_origin()
     info["mismatch_u"] = mismatch_u
@@ -383,28 +339,16 @@ def make_interface(film='',subs='',atol=1,ltol=0.05):
     info["area2"] = area2
     info["film_sl"] = film
     info["subs_sl"] = subs
-
-    
-    seperation=3
-    coords_uniq_sub = np.array(subs.cart_coords)
-
-
-    coords_uniq_film = np.array(film.cart_coords)
-
+    seperation = 3
     substrate_top_z = max(np.array(subs.frac_coords)[:, 2])
     substrate_bot_z = min(np.array(subs.frac_coords)[:, 2])
-
     film_bottom = min(np.array(film.frac_coords)[:, 2])
     film_top = max(np.array(film.frac_coords)[:, 2])
-
     sub_z = subs.lattice_mat[2, :]
-    origin = np.array([0, 0, substrate_top_z])
-    shift_normal = sub_z / np.linalg.norm(sub_z) * seperation/ np.linalg.norm(sub_z)
-
-    thickness_sub = abs(substrate_top_z-substrate_bot_z)
-    thickness_film = abs(film_top-film_bottom)
-
-
+    norm_sub_z = np.linalg.norm(sub_z)
+    shift_normal = sub_z / np.linalg.norm(sub_z) * seperation / norm_sub_z
+    thickness_sub = abs(substrate_top_z - substrate_bot_z)
+    thickness_film = abs(film_top - film_bottom)
     new_coords = []
     lattice_mat = subs.lattice_mat
     elements = []
@@ -417,25 +361,20 @@ def make_interface(film='',subs='',atol=1,ltol=0.05):
         elements.append(i)
     for i in film.frac_coords:
         tmp = i
-        tmp[2] = i[2] +shift_normal[2]+(thickness_sub+thickness_film)/2.0
-
-
+        thickness_sub_film = (thickness_sub + thickness_film) / 2.0
+        tmp[2] = i[2] + shift_normal[2] + thickness_sub_film
         new_coords.append(tmp)
-
-
-    interface = Atoms(
-        lattice_mat=lattice_mat, elements=elements, coords=new_coords, cartesian=False
-    )
-    info['interface']=interface
+    interface = Atoms(lattice_mat=lattice_mat, elements=elements,
+                      coords=new_coords, cartesian=False)
+    info['interface'] = interface
     return info
 
 
-
-
-def mismatch_strts(film=[], subs=[],ltol=0.05, atol=10):
+def mismatch_strts(film=[], subs=[], ltol=0.05, atol=10):
     """
-    Returns mismatch and other information as info dict,
-    Deprecated, this module will be removes in the next version
+    Return mismatch and other information as info dict.
+
+    Deprecated this module will be removes in the next version.
     """
     z = ZSLGenerator()
     matches = list(z(film.lattice_mat[:2], subs.lattice_mat[:2], lowest=True))
@@ -450,8 +389,6 @@ def mismatch_strts(film=[], subs=[],ltol=0.05, atol=10):
 
     uv1 = matches[0]["sub_sl_vecs"]
     uv2 = matches[0]["film_sl_vecs"]
-    # uv1=[[-8.52917200e+00,  9.12745800e+00,  3.66344517e-17],[1.27937580e+01, 9.12745800e+00, 1.34228735e-15]]
-    # uv2=[[7.02403800e+00, 1.05360570e+01, 1.07524571e-15],[-1.40480760e+01,  7.02403800e+00, -4.30098283e-16]]
     u = np.array(uv1)
     v = np.array(uv2)
     a1 = u[0]
@@ -476,44 +413,30 @@ def mismatch_strts(film=[], subs=[],ltol=0.05, atol=10):
     uv_substrate = uv1
     uv_mat2d = uv2
     substrate_latt = Lattice(
-        np.array([uv_substrate[0][:], uv_substrate[1][:], subs.lattice_mat[2, :]])
+        np.array([uv_substrate[0][:], uv_substrate[1][:],
+                 subs.lattice_mat[2, :]])
     )
-    # to avoid numerical issues with find_mapping
-    mat2d_fake_c = film.lattice_mat[2, :] / np.linalg.norm(film.lattice_mat[2, :]) * 5.0
-    mat2d_latt = Lattice(np.array([uv_mat2d[0][:], uv_mat2d[1][:], mat2d_fake_c]))
-    mat2d_latt_fake = Lattice(
-        np.array([film.lattice_mat[0, :], film.lattice_mat[1, :], mat2d_fake_c])
-    )
-    _, __, scell = subs.lattice.find_matches(substrate_latt, ltol=ltol, atol=atol)
+    film_norm = np.linalg.norm(film.lattice_mat[2, :])
+    mat2d_fake_c = film.lattice_mat[2, :] / film_norm * 5.0
+    mat2d_latt = Lattice(np.array([uv_mat2d[0][:],
+                         uv_mat2d[1][:], mat2d_fake_c]))
+    mat2d_latt_fake = Lattice(np.array([film.lattice_mat[0, :],
+                              film.lattice_mat[1, :], mat2d_fake_c]))
+    _, __, scell = subs.lattice.find_matches(substrate_latt,
+                                             ltol=ltol, atol=atol)
     scell[2] = np.array([0, 0, 1])
-    # print("subs lattice", subs.lattice_mat)
-    # print("scell", scell)
     subs = subs.make_supercell_matrix(scell)
     _, __, scell = mat2d_latt_fake.find_matches(mat2d_latt, ltol=0.05, atol=1)
     scell[2] = np.array([0, 0, 1])
     film = film.make_supercell_matrix(scell)
-    # modify the substrate lattice so that the 2d material can be
-    # grafted on top of it
-    #lmap = Lattice(
-    #    np.array(
-    #        [subs.lattice_mat[0, :], subs.lattice_mat[1, :], film.lattice_mat[2, :]]
-    #    )
-    #)
-    #film.lattice = lmap
 
     lmap = Lattice(
         np.array(
-            [subs.lattice_mat[0, :], subs.lattice_mat[1, :], film.lattice_mat[2, :]]
+            [subs.lattice_mat[0, :],
+             subs.lattice_mat[1, :], film.lattice_mat[2, :]]
         )
     )
     film.lattice = lmap
-
-
-
-    # film.modify_lattice(lmap)
-    # print ("film",film)
-    # print ("subs",subs)
-
     info["mismatch_u"] = mismatch_u
     info["mismatch_v"] = mismatch_v
     info["mismatch_angle"] = mismatch_angle
@@ -525,10 +448,10 @@ def mismatch_strts(film=[], subs=[],ltol=0.05, atol=10):
 
 
 def get_hetero_type(A={}, B={}):
+    """Provide heterojunction classification using Anderson rule."""
     stack = "na"
     int_type = "na"
     try:
-        # if A['phi']>B['phi']:
         if A["scf_vbm"] - A["avg_max"] < B["scf_vbm"] - B["avg_max"]:
             stack = "BA"
         else:
@@ -537,53 +460,33 @@ def get_hetero_type(A={}, B={}):
             A = D
             B = C
             stack = "AB"
-            # tmp=B
-            # B=A
-            # A=tmp
         vbm_a = A["scf_vbm"] - A["avg_max"]
         vbm_b = B["scf_vbm"] - B["avg_max"]
         cbm_a = A["scf_cbm"] - A["avg_max"]
         cbm_b = B["scf_cbm"] - B["avg_max"]
-        #  print ('vbm_a,vbm_b,cbm_b,cbm_a',vbm_a,vbm_b,cbm_b,cbm_a)
         if vbm_a < vbm_b and vbm_b < cbm_b and cbm_b < cbm_a:
             int_type = "I"
         elif vbm_a < vbm_b and vbm_b < cbm_a and cbm_a < cbm_b:
             int_type = "II"
         elif vbm_a < cbm_a and cbm_a < vbm_b and vbm_b < cbm_b:
             int_type = "III"
-    except:
+    except Exception:
         pass
     return int_type, stack
 
 
 def get_hetero(film, substrate, seperation=3.0):
-    # unique site coordinates in the substrate top layers
-    coords_uniq_sub = np.array(substrate.cart_coords)
-
-    # unique site coordinates in the 2D material bottom layers
-    coords_uniq_film = np.array(film.cart_coords)
-   
+    """Generate heterostructure."""
     substrate_top_z = max(np.array(substrate.cart_coords)[:, 2])
     substrate_bot_z = min(np.array(substrate.cart_coords)[:, 2])
-    #print ('substrate_top_z',substrate_top_z- substrate_bot_z)
     film_bottom = min(np.array(film.cart_coords)[:, 2])
     film_top = max(np.array(film.cart_coords)[:, 2])
-    #print ('film_bottom',film_top-film_bottom)
-    # shift normal to the surface by 'seperation'
     sub_z = substrate.lattice_mat[2, :]
     origin = np.array([0, 0, substrate_top_z])
     shift_normal = sub_z / np.linalg.norm(sub_z) * seperation
-    #print ('origin', origin)
-    #print ('shift_normal', shift_normal)
-    thickness_sub = abs(substrate_top_z-substrate_bot_z)
-    thickness_film = abs(film_top-film_bottom)
-    #shift_normal =  seperation
-    #shift_normal = sub_z / np.linalg.norm(sub_z) * seperation
-    # generate all possible interfaces, one for each combination of
-    # unique substrate and unique 2d materials site in the layers .i.e
-    # an interface structure for each parallel shift
-    # interface = 2D material + substrate
-
+    thickness_sub = abs(substrate_top_z - substrate_bot_z)
+    thickness_film = abs(film_top - film_bottom)
+    print('thickness_sub, thickness_film', thickness_sub, thickness_film)
     new_coords = []
     lattice_mat = substrate.lattice_mat
     elements = []
@@ -596,15 +499,12 @@ def get_hetero(film, substrate, seperation=3.0):
         elements.append(i)
     for i in film.cart_coords:
         tmp = i
-        #tmp[2] = i[2] + (thickness_sub+thickness_film)
-        #tmp[2] = i[2] +(thickness_sub+thickness_film)+seperation
-        #tmp = tmp  + shift_normal
         tmp = tmp + origin + shift_normal
-        #new_coords.append(i)
         new_coords.append(tmp)
 
     interface = Atoms(
-        lattice_mat=lattice_mat, elements=elements, coords=new_coords, cartesian=True
+        lattice_mat=lattice_mat, elements=elements,
+        coords=new_coords, cartesian=True
     )
 
     return interface
