@@ -1,34 +1,40 @@
 """
-Downloads files from https://figshare.com/authors/Kamal_Choudhary/4445539
+Downloads files from Figshare.
+
+Main page: https://figshare.com/authors/Kamal_Choudhary/4445539
 """
 
-import zipfile, os, requests
+import zipfile
+import os
+import requests
 from jarvis.db.jsonutils import loadjson
 
+
 def datasets(dataset=''):
+    """Get collection of dataset names and URLs."""
     if dataset == 'dft_2d':
         url = "https://ndownloader.figshare.com/files/22471019"
         js_tag = 'jdft_2d-4-26-2020.json'
-        print ('Downloading 2D dataset ...')
+        print('Obtaining 2D dataset ...')
     elif dataset == 'dft_3d':
         url = "https://ndownloader.figshare.com/files/22471022"
-        js_tag = 'jdft_3d-4-26-2020.json' 
-        print ('Downloading 3D dataset ...')
+        js_tag = 'jdft_3d-4-26-2020.json'
+        print('Obtaining 3D dataset ...')
 
     elif dataset == 'cfid_3d':
         url = "https://ndownloader.figshare.com/files/22470818"
-        js_tag = 'jml_3d-4-26-2020.json' 
-        print ('Downloading 3D CFID dataset ...')
+        js_tag = 'jml_3d-4-26-2020.json'
+        print('Obtaining 3D CFID dataset ...')
     else:
-        ValueError('Dataset doesnt exist',dataset)
+        ValueError('Dataset doesnt exist', dataset)
     return url, js_tag
 
-    
 
-def data(dataset='dft_2d') :
+def data(dataset='dft_2d'):
+    """Provide main function to download datasets."""
     url, js_tag = datasets(dataset)
-    path = str(os.path.join(os.path.dirname(__file__),js_tag ))
-    if not  os.path.isfile(path):
+    path = str(os.path.join(os.path.dirname(__file__), js_tag))
+    if not os.path.isfile(path):
         zfile = str(os.path.join(os.path.dirname(__file__), "tmp.zip"))
         r = requests.get(url)
         f = open(zfile, "wb")
@@ -36,16 +42,15 @@ def data(dataset='dft_2d') :
         f.close()
 
         with zipfile.ZipFile(zfile, 'r') as zipObj:
-            #zipObj.extract(path)
+            # zipObj.extract(path)
             zipObj.extractall(os.path.join(os.path.dirname(__file__)))
         os.remove(zfile)
     data = loadjson(path)
     return data
 
 
-
-
 def get_ff_eneleast():
+    """Get JARVIS-FF related data."""
     jff1 = str(os.path.join(os.path.dirname(__file__), "jff1.json"))
     if not os.path.isfile(jff1):
         r = requests.get("https://ndownloader.figshare.com/files/10307139")
@@ -56,7 +61,6 @@ def get_ff_eneleast():
     return data_ff1
 
 
-
 """
 if __name__ == "__main__":
 
